@@ -1344,3 +1344,143 @@ def _pin(state: ChessState, kp: int):
     for i in range(8):
         pins = _direction_pin(bs, turn, kp, i, pins)
     return pins
+
+
+def _to_fen(state: ChessState):
+    """Convert state into fen expression.
+
+    - ポーン:P ナイト:N ビショップ:B ルーク:R クイーン:Q キング:K
+    - 先手の駒は大文字、後手の駒は小文字で表現
+    - 空白の場合、連続する空白の数を入れて次の駒にシフトする。P空空空RならP3R
+    - 左上から開始して右に見ていく
+    - 段が変わるときは/を挿入
+    - 盤面の記入が終わったら手番（w/b）
+    - キャスリングの可否。キングサイドにできる場合はK, クイーンサイドにできる場合はQを先後それぞれ書く。全部不可なら-
+    - アンパッサン可能な位置。ポーンが2マス動いた場合はそのポーンが通過した位置を記録
+    - 最後にポーンの移動および駒取りが発生してからの手数と通常の手数（0, 1で固定にする）
+
+    >>> s = init()
+    >>> _to_fen(s)
+    'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1'
+    """
+    pb = _board_status(state)
+    pb = np.rot90(pb.reshape((8, 8)), k=1)
+    fen = ""
+    # fmt: off
+    board_char_dir = ["", "P", "N", "B", "R", "Q", "K", "p", "n", "b", "r", "q", "k"]
+    board_line_dir = ["a", "b", "c", "d", "e", "f", "g", "h"]
+    # fmt: on
+    # 盤面
+    for i in range(8):
+        space_length = 0
+        for j in range(8):
+            piece = pb[i, j]
+            if piece == 0:
+                space_length += 1
+            elif space_length != 0:
+                fen += str(space_length)
+                space_length = 0
+            if piece != 0:
+                fen += board_char_dir[piece]
+        if space_length != 0:
+            fen += str(space_length)
+        if i != 7:
+            fen += "/"
+        else:
+            fen += " "
+    # 手番
+    if state.turn == 0:
+        fen += "w "
+    else:
+        fen += "b "
+    # キャスリング
+    wk_cas = not state.wk_move_count and not state.wr2_move_count
+    wq_cas = not state.wk_move_count and not state.wr1_move_count
+    bk_cas = not state.bk_move_count and not state.br2_move_count
+    bq_cas = not state.bk_move_count and not state.br1_move_count
+    if not wk_cas and not wq_cas and not bk_cas and not bq_cas:
+        fen += "- "
+    else:
+        if wk_cas:
+            fen += "K"
+        if wq_cas:
+            fen += "Q"
+        if bk_cas:
+            fen += "k"
+        if bq_cas:
+            fen += "q"
+        fen += " "
+    # アンパッサン
+    if state.en_passant == -1:
+        fen += "- "
+    else:
+        if state.turn == 0:
+            en = state.en_passant + 1
+        else:
+            en = state.en_passant - 1
+        fen += board_line_dir[en // 8]
+        fen += str(en % 8 + 1)
+        fen += " "
+    fen += "0 1"
+    return fen
+
+
+def _from_fen(fen):
+    # fmt: off
+    board_char_dir = ["", "P", "N", "B", "R", "Q", "K", "p", "n", "b", "r", "q", "k"]
+    board_line_dir = ["a", "b", "c", "d", "e", "f", "g", "h"]
+    # fmt: on
+    board, turn, cas, en, _, _ = fen.split()
+    board_ranks = board.split("/")
+    piece_board = np.zeros(64, dtype=np.int8)
+    for i in range(8):
+        file = board_ranks[i]
+        rank = []
+        for char in file:
+            if char.isdigit():
+                num_space = int(char)
+                for j in range(num_space):
+                    rank.append(0)
+            else:
+                piece = board_char_dir.index(char)
+                rank.append(piece)
+        for j in range(8):
+            piece_board[8 * j + 7 - i] = rank[j]
+    if turn == "w":
+        s_turn = np.int8(0)
+    else:
+        s_turn = np.int8(1)
+    move_count = [True, True, True, True, True, True]
+    if cas != "-":
+        for char in cas:
+            if char == "K":
+                move_count[0] = False
+                move_count[2] = False
+            if char == "Q":
+                move_count[0] = False
+                move_count[1] = False
+            if char == "k":
+                move_count[3] = False
+                move_count[5] = False
+            if char == "q":
+                move_count[3] = False
+                move_count[4] = False
+    if en != "-":
+        point = board_line_dir.index(en[0]) * 8 + int(en[1]) - 1
+        if s_turn == 0:
+            point -= 1
+        else:
+            point += 1
+    else:
+        point = -1
+    return ChessState(
+        turn=s_turn,
+        board=_make_board(piece_board),
+        wk_move_count=move_count[0],
+        wr1_move_count=move_count[1],
+        wr2_move_count=move_count[2],
+        bk_move_count=move_count[3],
+        br1_move_count=move_count[4],
+        br2_move_count=move_count[5],
+        en_passant=point,
+    )
